Pool de identidades de máquinas com identidade associada ao Microsoft Entra

Last published : Nov 03, 2026
Este artigo descreve como criar um pool de identidades de máquinas com identidade associada ao Microsoft Entra usando o Citrix DaaS.
Para obter informações sobre requisitos, limitações e considerações, consulte Associado ao Microsoft Entra.
Antes de criar o catálogo de máquinas, você precisa do seguinte:
  1. Novo local de recurso
    • navegar para a UI de administração do Citrix Cloud™ > menu hambúrguer superior esquerdo > Locais de Recursos.
    • Clique em + Local de Recurso.
    • Insira um nome para o novo local de recurso e clique em Salvar.
  2. Crie uma conexão de hospedagem. Consulte a seção Criar e gerenciar conexões para obter detalhes. Ao implantar máquinas no Azure, consulte Conexão com o Azure Resource Manager.
Você pode criar catálogos associados ao Microsoft Entra usando o Studio ou o PowerShell.

Usar o Studio

As informações a seguir são um suplemento às orientações em Criar catálogos de máquinas. Para criar catálogos associados ao Microsoft Entra, siga as orientações gerais desse artigo, observando os detalhes específicos dos catálogos associados ao Microsoft Entra.
No assistente de criação de catálogo:
  1. Na página Imagem:
    • Selecione 2106 ou posterior como o nível funcional.
    • Selecione Usar um perfil de máquina e selecione a máquina apropriada da lista.
  2. Na página Identidades da Máquina:
    1. Selecione Ingressado no Microsoft Entra. As máquinas criadas são de propriedade de uma organização e são acessadas com uma conta do Microsoft Entra que pertence a essa organização. Elas existem apenas na nuvem.
      Nota:
      • O tipo de identidade Ingressado no Microsoft Entra requer a versão 2106 ou posterior como nível funcional mínimo para o catálogo.
      • As máquinas são ingressadas no domínio Microsoft Entra associado ao locatário ao qual a conexão de hospedagem está vinculada.
    2. Clique em Selecionar conta de serviço e selecione uma conta de serviço disponível na lista. Se uma conta de serviço adequada não estiver disponível para o locatário do Microsoft Entra ao qual as identidades da máquina serão ingressadas, você poderá criar uma conta de serviço. Para obter informações sobre a conta de serviço, consulte Contas de serviço do Microsoft Entra.
      Nota:
      A conta de serviço que você selecionou pode estar em um status não íntegro devido a vários motivos. Você pode ir para Administradores > Contas de Serviço para visualizar detalhes e corrigir os problemas de acordo com as recomendações. Alternativamente, você pode prosseguir com a operação do catálogo de máquinas e corrigir os problemas mais tarde. Se você não corrigir o problema, dispositivos ingressados no Microsoft Entra ou registrados no Microsoft Intune obsoletos serão gerados, o que pode bloquear o ingresso das máquinas no Microsoft Entra.
    3. Clique em Adicionar Atributos de Extensão para armazenar dados exclusivos e personalizados diretamente em seus objetos de dispositivo do Entra ID. Na página Adicionar Atributos de Extensão, adicione Atributos de extensão e Valor.
      Nota:
      • Você pode adicionar um máximo de 15 atributos de extensão.
      • O nome deve ser exclusivo e o valor não pode estar vazio.
    4. Selecione uma opção de conta do Active Directory:
      • Criar novas contas do Active Directory:
        • Se você selecionar Criar novas contas do Active Directory e usar um pool de identidades existente para criar novas contas, selecione um domínio para essas contas e especifique um esquema de nomenclatura de conta.
        • Se você selecionar Criar novas contas do Active Directory e usar um pool de identidades existente para criar novas contas, selecione um pool de identidades na lista.
      • Usar contas existentes do Active Directory: Você pode procurar ou importar de um arquivo CSV e redefinir a senha ou especificar a mesma senha para todas as contas.
    • Especifique um esquema de nomenclatura de conta.
Os usuários devem ter acesso explícito concedido no Azure para fazer login nas máquinas usando suas credenciais do Microsoft Entra. Consulte a seção Microsoft Entra joined para obter mais detalhes.

Adicionar ou modificar atributos de extensão

Para alterar ou adicionar atributos de extensão adicionais a um catálogo de máquinas MCS existente, ou adicionar atributos de extensão a um catálogo MCS sem uma conta de serviço, use o assistente Editar Catálogo de Máquinas.
  • Para alterar ou adicionar atributos de extensão adicionais, navegar até a página Atributos de Extensão de Dispositivo do Microsoft Entra. Clique no ícone de lápis e adicione ou atualize os atributos de extensão.
  • Para adicionar atributos de extensão a um catálogo MCS sem uma conta de serviço do Microsoft Entra:
    1. navegar até a página Conta de Serviço. Selecione uma conta de serviço do Microsoft Entra para o Microsoft Intra ID.
    2. Vá para a página Atributos de Extensão de Dispositivo do Microsoft Entra, clique em Adicionar Atributos de Extensão.

Modificar a associação da conta de serviço

Para alterar a conta de serviço associada ou adicionar uma associação a um catálogo de máquinas MCS existente, use a página Editar Catálogo de Máquinas.
  • Para adicionar uma conta de serviço, clique em Selecionar conta de serviço na página Conta de Serviço.
  • Para alterar a associação da conta de serviço, clique no ícone de edição na página Conta de Serviço.

Usar PowerShell

A seguir estão as etapas do PowerShell equivalentes às operações no Studio.
A diferença entre catálogos unidos ao AD local e catálogos unidos ao Microsoft Entra reside na criação do pool de identidades e no esquema de provisionamento.
Você deve associar uma conta de serviço do Microsoft Entra ao pool de identidades e, em seguida, criar o catálogo de máquinas. Você pode criar um novo pool de identidades ou atualizar um pool de identidades existente para associá-lo a uma conta de serviço.

Criar novo pool de identidades

Por exemplo: Para criar um novo pool de identidades e associá-lo a uma conta de serviço, execute o seguinte:
New-AcctIdentityPool -IdentityType AzureAD -IdentityPoolName MyPool -NamingScheme Acc#### -NamingSchemeType Numeric -ServiceAccountUid $serviceAccountUid
Por exemplo: Para criar um novo pool de identidades com atributos de extensão especificados e associá-lo a uma conta de serviço, execute o seguinte:
New-AcctIdentityPool -IdentityPoolName MyPool -NamingScheme ACC#### -NamingSchemeType Numeric -Domain "abc.local" -IdentityType AzureAD -ServiceAccountUid $serviceAccountUid -EntraIDExtensionAttributes @{"extensionAttribute1" = "val1"; "extensionAttribute2" = "val2"}
Quando uma VM é ligada pela primeira vez, após ingressar no Microsoft Entra ID, a VM reporta seu deviceId do Entra ID ao MCS.
Por exemplo: Para verificar o EntraIDDeviceID, execute Get-AcctADAccount ou Get-AcctIdentity.
Get-AcctADAccount -IdentityPoolName MyPool
Após a reinicialização, para VMs persistentes, o EntraIDDeviceID permanece o mesmo. Para VMs não persistentes, há um novo EntraIDDeviceID após cada reinicialização.
Nota:
O MCS remove automaticamente os atributos de extensão associados quando você exclui uma VM do catálogo, mas não a exclui do Azure.

Atualizar pool de identidades existente

Por exemplo: Para atualizar um pool de identidades existente para associá-lo a uma conta de serviço, execute o seguinte:
$identityPoolUid = (Get-ProvScheme -ProvisioningSchemeName "MyProvScheme").IdentityPoolUid
Set-AcctIdentityPool -IdentityPoolUid $identityPoolUid -ServiceAccountUid $serviceAccountUid
Nota:
O $serviceAccountUid deve ser um UID válido de uma conta de serviço do Microsoft Entra.
Por exemplo: Para editar atributos de extensão para o catálogo existente, execute o seguinte:
Nota:
  • Após atualizar as VMs do catálogo existente para a versão VDA 2511 ou posterior, é necessário reiniciar. Essa reinicialização permite que a VM relate seu deviceId do Entra ID ao MCS, permitindo que o MCS configure os atributos de extensão da VM.
  • O catálogo existente deve ter um tipo de conta de serviço AzureAD com permissão "Device.ReadWrite.All".
Para adicionar novos atributos:
Set-AcctIdentityPool -IdentityPoolName MyPool -EntraIDExtensionAttributes @{"extensionAttribute1" = "val1"; "extensionAttribute2" = "val2"}
Para remover alguns atributos existentes
Set-AcctIdentityPool -IdentityPoolName MyPool -EntraIDExtensionAttributes @{}
OU
Set-AcctIdentityPool -IdentityPoolName MyPool -EntraIDExtensionAttributes @{extensionAttribute1 = ""; extensionAttribute2 = ""}
Set-AcctIdentityPool também atualiza os atributos de extensão do dispositivo Entra ID para VMs que já estão unidas ao Entra ID e possuem um valor EntraIDDeviceID em suas identidades.

Criar catálogos unidos ao Microsoft Entra

Para criar um esquema de provisionamento para catálogos unidos ao Microsoft Entra, o parâmetro MachineProfile é necessário em New-ProvScheme. Por exemplo:
New-ProvScheme -CustomProperties "<CustomProperties xmlns=`"http://schemas.citrix.com/2014/xd/machinecreation`" xmlns:xsi=`"http://www.w3.org/2001/XMLSchema-instance`"><Property xsi:type=`"StringProperty`" Name=`"UseManagedDisks`" Value=`"true`" /><Property xsi:type=`"StringProperty`" Name=`"StorageType`" Value=`"StandardSSD_LRS`" /><Property xsi:type=`"StringProperty`" Name=`"LicenseType`" Value=`"Windows_Server`" /></CustomProperties>" -HostingUnitName "AzureResource" -IdentityPoolName "AzureADJoinedCatalog" -InitialBatchSizeHint 1 -MachineProfile "XDHyp:\HostingUnits\AzureResource\image.folder\azuread-rg.resourcegroup\MasterVDA.vm" -MasterImageVM "XDHyp:\HostingUnits\AzureResource\image.folder\azuread-rg.resourcegroup\azuread-small_OsDisk_1_5fb42fadf7ff460bb301ee0d56ea30da.manageddisk" -NetworkMapping @{"0"="XDHyp:\HostingUnits\AzureResource\virtualprivatecloud.folder\East US.region\virtualprivatecloud.folder\azuread-rg.resourcegroup\azuread-vnet.virtualprivatecloud\Test_VNET.network"} -ProvisioningSchemeName "AzureADJoinedCatalog" -RunAsynchronously -Scope @() -SecurityGroup @() -ServiceOffering "XDHyp:\HostingUnits\AzureResource\serviceoffering.folder\Standard_DS1_v2.serviceoffering"
Para criar um catálogo Microsoft Entra usando uma imagem preparada. Por exemplo:
New-ProvScheme -ProvisioningSchemeName <name> -ImageVersionSpecUid <preparedVersionSpecUid> -HostingUnitUid <hostingUnitUid> -IdentityPoolUid <IdentityPoolUid> [-CleanOnBoot] -NetworkMapping @{"0"="XDHyp:\HostingUnits\<hostingunitName>\<region>.region\virtualprivatecloud.folder\<resourcegroupName>.resourcegroup\<vnetName>.virtualprivatecloud\<sunNetName>.network"} -ServiceOffering <serviceofferingPath> [-MachineProfile <machineProfilePath>] [-CustomProperties <>]

Visualizar o status do processo de união ao Microsoft Entra

No Studio, o status do processo de união ao Microsoft Entra é visível quando as máquinas unidas ao Microsoft Entra em um grupo de entrega estão em estado ligado. Para visualizar o status, use Pesquisar para identificar essas máquinas e, em seguida, para cada uma, verifique Identidade da Máquina na guia Detalhes no painel inferior. As seguintes informações podem aparecer em Identidade da Máquina:
  • Unido ao Microsoft Entra
  • Ainda não ingressado no Microsoft Entra ID
Nota:
Se as máquinas não conseguirem entrar no estado de ingresso no Microsoft Entra, elas não se registrarão no Delivery Controller. O status de registro delas aparecerá como Inicialização.
Além disso, usando o Studio, você pode descobrir por que as máquinas estão indisponíveis. Para fazer isso, clique em uma máquina no nó Pesquisar, verifique Registro na guia Detalhes no painel inferior e, em seguida, leia a dica de ferramenta para obter informações adicionais.

Grupo de Entrega

Consulte a seção Criar grupos de entrega para obter detalhes.

Habilitar Rendezvous

Depois que o grupo de entrega for criado, você poderá habilitar o Rendezvous. Consulte Rendezvous V2 para obter detalhes.

Solução de problemas

Se as máquinas não conseguirem ingressar no Microsoft Entra, faça o seguinte:
  • Verifique se a identidade gerenciada atribuída ao sistema está habilitada para as máquinas. As máquinas provisionadas por MCS devem ter isso habilitado automaticamente. O processo de ingresso no Microsoft Entra falha sem uma identidade gerenciada atribuída ao sistema. Se a identidade gerenciada atribuída ao sistema não estiver habilitada para máquinas provisionadas por MCS, a possível razão é:
    • IdentityType do pool de identidades associado ao esquema de provisionamento não está definido como AzureAD. Você pode verificar isso executando Get-AcctIdentityPool.
  • Para catálogos que usam imagens mestre com VDA versão 2206 ou anterior, verifique o status de provisionamento da extensão AADLoginForWindows para as máquinas. Se a extensão AADLoginForWindows não existir, as possíveis razões são:
    • IdentityType do pool de identidades associado ao esquema de provisionamento não está definido como AzureAD. Você pode verificar isso executando Get-AcctIdentityPool.
    • A instalação da extensão AADLoginForWindows está bloqueada pela política do Azure.
  • Para solucionar problemas de falhas de provisionamento da extensão AADLoginForWindows, você pode verificar os logs em C:\WindowsAzure\Logs\Plugins\Microsoft.Azure.ActiveDirectory.AADLoginForWindows na máquina provisionada pelo MCS.
    Nota:
    O MCS não depende da extensão AADLoginForWindows para unir uma VM ao Microsoft Entra ID ao usar uma imagem mestre com VDA versão 2209 ou posterior. Neste caso, a extensão AADLoginForWindows não será instalada na máquina provisionada pelo MCS. Portanto, os logs de provisionamento da extensão AADLoginForWindows não podem ser coletados.
  • Verifique o status de junção do Microsoft Entra e os logs de depuração executando o comando dsregcmd /status na máquina provisionada pelo MCS.
  • Verifique os logs de eventos do Windows em Logs de Aplicativos e Serviços > Microsoft > Windows > Registro de Dispositivo de Usuário.
  • Verifique se o gerenciamento de dispositivos do Microsoft Entra está configurado corretamente executando Get-Item -LiteralPath XDHyp:\Connections\${HostingConnectionName}.
    Certifique-se de que o valor de:
    • a propriedade AzureAdDeviceManagement em CustomProperties seja true
    • a propriedade Citrix_MCS_AzureAdDeviceManagement_PermissionGranted nos metadados seja true
    Se Citrix_MCS_AzureAdDeviceManagement_PermissionGranted for false, isso indica que o ServicePrincipal do aplicativo usado pela conexão de hospedagem não tem permissões suficientes para realizar o gerenciamento de dispositivos do Microsoft Entra. Para resolver isso, atribua ao ServicePrincipal a função de Administrador de Dispositivo na Nuvem.

Grupos de segurança dinâmicos do Microsoft Entra

As regras de grupo dinâmico colocam as VMs no catálogo em um grupo de segurança dinâmico com base no esquema de nomenclatura do catálogo de máquinas.
Se o esquema de nomenclatura do catálogo de máquinas for Test### (onde # significa número), a Citrix® cria a regra de associação dinâmica \^Test{3}$ no grupo de segurança dinâmico. Agora, se o nome da VM criada pela Citrix for qualquer um de Test001 a Test999, a VM será incluída no grupo de segurança dinâmico.
Nota:
Se o nome da VM criada por você manualmente for qualquer um de Test001 a Test999, a VM também será incluída no grupo de segurança dinâmico. Esta é uma das limitações do grupo de segurança dinâmico.
O recurso de grupo de segurança dinâmico é útil quando você deseja gerenciar as VMs pelo Microsoft Entra ID. Isso também é útil quando você deseja aplicar políticas de Acesso Condicional ou distribuir aplicativos do Intune filtrando as VMs com o grupo de segurança dinâmico do Microsoft Entra.
Você pode usar comandos do PowerShell para:
  • Criar um catálogo de máquinas com grupo de segurança dinâmico do Microsoft Entra
  • Habilitar o recurso de grupo de segurança para um catálogo do Microsoft Entra
  • Excluir um catálogo de máquinas com grupo de segurança de dispositivo unido ao Microsoft Entra
Importante:
  • Para criar um catálogo de máquinas com grupo de segurança dinâmico do Microsoft Entra, adicionar máquinas ao catálogo e excluir o catálogo de máquinas, você deve ter um token de acesso do Microsoft Entra. Para obter informações sobre como obter o token de acesso do Microsoft Entra, consulte <https://docs.microsoft.com/pt-br/graph/graph-explorer/graph-explorer-features#consent-to-permissions/>.
  • Para solicitar um token de acesso no Microsoft Entra ID, a Citrix solicita a permissão Group.ReadWrite.All para a API Microsoft Graph. Um usuário do Microsoft Entra que tenha permissão de consentimento de administrador em todo o locatário pode conceder a permissão Group.ReadWrite.All para a API Microsoft Graph. Para obter informações sobre como conceder consentimento de administrador em todo o locatário a um aplicativo no Microsoft Entra ID, consulte o documento da Microsoft <https://learn.microsoft.com/pt-br/entra/identity/enterprise-apps/grant-admin-consent>.
  • Você não precisa de um token de acesso do Microsoft Entra se usar uma conta de serviço do Microsoft Entra. Para obter informações sobre contas de serviço, consulte Contas de serviço para gerenciamento de identidade de máquina.

Criar um catálogo de máquinas com grupo de segurança dinâmico do Microsoft Entra

  1. Na interface do usuário de configuração do catálogo de máquinas do console baseado na web, na página Identidades da Máquina, selecione Unido ao Microsoft Entra.
  2. Faça login no Microsoft Entra ID.
  3. Obtenha o token de acesso para a API MS Graph. Use este token de acesso como valor do parâmetro $AzureADAccessToken ao executar os comandos do PowerShell. Você não precisa de um token de acesso do Microsoft Entra se usar uma conta de serviço do Microsoft Entra.
  4. Execute o seguinte comando para verificar se o nome do grupo de segurança dinâmico existe no locatário.
    Get-AcctAzureADSecurityGroup
    –AccessToken  $AzureADAccessToken
    –Name "SecurityGroupName"
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroup -ServiceAccountUid <service account uid> –Name "SecurityGroupName"
  5. Crie um catálogo de máquinas usando o ID do locatário, o token de acesso e o grupo de segurança dinâmico. Execute o seguinte comando para criar um IdentityPool com IdentityType=AzureAD e criar um grupo de segurança dinâmico no Azure.
    New-AcctIdentityPool
    -AllowUnicode
    -IdentityPoolName "SecurityGroupCatalog"
    -NamingScheme "SG-VM-###"
    -NamingSchemeType "Numeric" -Scope @()
    -ZoneUid "81291221-d2f2-49d2-ab12-bae5bbd0df05"
    -WorkgroupMachine
    -IdentityType "AzureAD"
    -DeviceManagementType "None"
    -AzureADTenantId  620387bb-9167-4bdd-8435-e3dccc58369e
    -AzureADSecurityGroupName "SecurityGroupName"
    -AzureADAccessToken $AzureADAccessToken
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    New-AcctIdentityPool  -AllowUnicode -AzureADSecurityGroupName "<security group name>" -AzureADTenantId "<Azure tenant id>" -DeviceManagementType "Intune" -IdentityPoolName "dynamic security group test" -IdentityType "AzureAD"  -NamingScheme "<naming scheme>" -NamingSchemeType "Numeric" -Scope @() -ServiceAccountUid @("<service account uid>") -StartCount 1 -WorkgroupMachine -ZoneUid "<Zone UID>"

Habilitar o recurso de grupo de segurança para um catálogo do Microsoft Entra

Você pode habilitar o recurso de segurança dinâmica para um catálogo do Microsoft Entra que foi criado sem o recurso de grupo de segurança dinâmica habilitado. Para fazer isso:
  1. Crie manualmente um novo grupo de segurança dinâmico. Você também pode reutilizar um grupo de segurança dinâmico existente.
  2. Faça login no Microsoft Entra ID e obtenha o token de acesso para a API MS Graph. Use este token de acesso como valor do parâmetro $AzureADAccessToken ao executar os comandos do PowerShell.
    Nota:
    • Para obter informações sobre as permissões exigidas pelo usuário do Microsoft Entra, consulte <https://learn.microsoft.com/pt-br/entra/identity/enterprise-apps/grant-admin-consent?pivots=portal#prerequisites/>.
    • Você não precisa de um token de acesso do Microsoft Entra se usar uma conta de serviço do Microsoft Entra.
  3. Execute o seguinte comando para conectar o pool de identidades ao grupo de segurança dinâmico do Microsoft Entra criado.
    Set-AcctIdentityPool
    -IdentityPoolName "SecurityGroupCatalog"
    -AzureADTenantId 620387bb-9167-4bdd-8435-e3dccc58369e
    -AzureADSecurityGroupNam "ExistingSecurityGroupName"
    -AzureADAccessToken $AzureADAccessToken
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Set-AcctIdentityPool
    -IdentityPoolName "SecurityGroupCatalog"
    -AzureADTenantId 620387bb-9167-4bdd-8435-e3dccc58369e
    -AzureADSecurityGroupNam "ExistingSecurityGroupName"
    -ServiceAccountUid @("<service account uid>") -StartCount 1 -WorkgroupMachine -ZoneUid "<Zone UID>"
Se você atualizar o esquema de nomenclatura, o Citrix atualizará o esquema de nomenclatura para uma nova regra de associação. Se você excluir o catálogo, a regra de associação será excluída, e não o grupo de segurança.

Excluir um catálogo de máquinas com grupo de segurança de dispositivo associado ao Microsoft Entra

Ao excluir um catálogo de máquinas, o grupo de segurança de dispositivo associado ao Microsoft Entra também é excluído.
Para excluir o grupo de segurança dinâmico do Microsoft Entra, faça o seguinte:
  1. Faça login no Microsoft Entra ID.
  2. Obtenha o token de acesso para a API do MS Graph. Use este token de acesso como valor do parâmetro $AzureADAccessToken ao executar os comandos do PowerShell. Você não precisa de um token de acesso do Microsoft Entra se usar uma conta de serviço do Microsoft Entra.
  3. Execute o seguinte comando:
    Remove-AcctIdentityPool
    -IdentityPoolName "SecurityGroupCatalog"
    -AzureADAccessToken $AzureADAccessToken
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Remove-AcctIdentityPool
    -IdentityPoolName "SecurityGroupCatalog"
    -ServiceAccountUid @("<service account uid>") -StartCount 1 -WorkgroupMachine -ZoneUid "<Zone UID>"

Crie um grupo de segurança dinâmico do Microsoft Entra sob um grupo de segurança atribuído do Microsoft Entra ID existente

Você pode criar um grupo de segurança dinâmico do Microsoft Entra sob um grupo de segurança atribuído do Microsoft Entra ID existente. Você pode fazer o seguinte:
  • Obtenha informações do grupo de segurança.
  • Obtenha todos os grupos de segurança atribuídos do Microsoft Entra ID que são sincronizados de um servidor AD local ou os grupos de segurança atribuídos aos quais as funções do Microsoft Entra podem ser atribuídas.
  • Obtenha todos os grupos de segurança dinâmicos do Microsoft Entra.
  • Adicione o grupo de segurança dinâmico do Microsoft Entra como membro do grupo atribuído do Microsoft Entra ID.
  • Remova a associação entre o grupo de segurança dinâmico do Microsoft Entra e o grupo de segurança atribuído do Microsoft Entra ID quando o grupo de segurança dinâmico do Microsoft Entra for excluído junto com o catálogo de máquinas.
Você também pode ver mensagens de erro explícitas quando qualquer uma das operações falhar.
Requisito:
Você deve ter o token de acesso para a API do MS Graph ao executar os comandos do PowerShell. Você não precisa de um token de acesso do Microsoft Entra se usar uma conta de serviço do Microsoft Entra. Portanto, em vez de -AccessToken <token>, use ServiceAccountUid <service account uid>.
Para obter o token de acesso:
  1. Abra Microsoft graph explorer e faça login no Microsoft Entra ID.
  2. Certifique-se de que você tenha consentimento para as permissões Group.ReadWrite.All e GroupMember.ReadWrite.All.
  3. Obtenha o token de acesso do Microsoft graph explorer. Use este token de acesso ao executar os comandos PowerShell.
Para obter informações do grupo de segurança por ID do grupo:
  1. Obtenha o token de acesso.
  2. Encontre a ID do objeto do grupo no portal do Azure.
  3. Execute o seguinte comando PowerShell no console do PowerShell:
    Get-AcctAzureADSecurityGroup
    -AccessToken <token> -GroupId <GroupUid>
    Ou, execute o seguinte se você estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroup -ServiceAccountUid <guid> -GroupId <GroupUid>
Para obter grupos de segurança pelo nome de exibição do grupo:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console do PowerShell:
    Get-AcctAzureADSecurityGroup
    -AccessToken <token>
    -Name <TargetGroupDisplayName>
    Ou, execute o seguinte se você estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroup
    -ServiceAccountUid <guid>
    -Name <TargetGroupDisplayName>
Para obter grupos de segurança cujo nome de exibição contém uma substring:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console do PowerShell:
    Get-AcctAzureADSecurityGroup
    -AccessToken <token>
    -SearchString <displayNameSubString>
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroup
    -ServiceAccountUid <guid>
    -SearchString <displayNameSubString>
Para obter todos os grupos de segurança atribuídos ao Microsoft Entra ID que são sincronizados de um servidor AD local ou os grupos de segurança atribuídos aos quais as funções do Microsoft Entra podem ser atribuídas:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console do PowerShell:
    Get-AcctAzureADSecurityGroup
    -AccessToken <token>
    -Assigned true
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroup
    -ServiceAccountUid <guid>
    -Assigned true
Para obter todos os grupos de segurança dinâmicos do Microsoft Entra:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console do PowerShell:
    Get-AcctAzureADSecurityGroup
    -AccessToken <token>
    -Dynamic true
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroup
    -ServiceAccountUid <guid>
    -Dynamic true
Para obter grupos de segurança atribuídos ao Microsoft Entra ID com contagem máxima de registros:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console do PowerShell:
    Get-AcctAzureADSecurityGroup
    -AccessToken <token>
    -Assigned true
    -MaxRecordCount 10
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroup
    -ServiceAccountUid <guid>
    -Assigned true
    -MaxRecordCount 10
Para adicionar um grupo de segurança dinâmico do Microsoft Entra como membro de um grupo de segurança atribuído ao Microsoft Entra ID:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console PowerShell:
    Add-AcctAzureADSecurityGroupMember
    -AccessToken <token>
    -GroupId <ASG-Id>
    -RefGroupId <DSG-Id>
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Add-AcctAzureADSecurityGroupMember
    -ServiceAccountUid <guid>
    -GroupId <ASG-Id>
    -RefGroupId <DSG-Id>
Para obter membros do grupo de segurança atribuído ao Microsoft Entra ID:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console PowerShell:
    Get-AcctAzureADSecurityGroupMember
    -AccessToken <token>
    -GroupId <ASG-Id>
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Get-AcctAzureADSecurityGroupMember
    -ServiceAccountUid <guid>
    -GroupId <ASG-Id>
    Nota:
    Get-AcctAzureADSecurityGroupMember fornece apenas os membros diretos do tipo de grupo de segurança sob o grupo de segurança atribuído ao Microsoft Entra ID.
Para remover a associação entre o grupo de segurança dinâmico do Microsoft Entra e o grupo de segurança atribuído ao Microsoft Entra ID quando o grupo de segurança dinâmico do Microsoft Entra é excluído junto com o catálogo de máquinas:
  1. Obtenha o token de acesso.
  2. Execute o seguinte comando PowerShell no console PowerShell:
    Remove-AcctIdentityPool
    -IdentityPoolName "SecurityGroupCatalog"
    -AzureADAccessToken $AzureADAccessToken
    Ou, execute o seguinte se estiver usando uma conta de serviço do Microsoft Entra:
    Remove-AcctIdentityPool
    -ServiceAccountUid <guid>
    -IdentityPoolName "SecurityGroupCatalog"

Modificar nome do grupo de segurança dinâmico do Microsoft Entra

Você pode modificar o nome do grupo de segurança dinâmico do Microsoft Entra associado a um catálogo de máquinas. Essa modificação faz com que as informações do grupo de segurança armazenadas no objeto do pool de identidades do Microsoft Entra sejam consistentes com as informações armazenadas no portal do Azure.
Nota:
Os grupos de segurança dinâmicos do Microsoft Entra não incluem grupos de segurança sincronizados do AD local e outros tipos de grupo, como o grupo do Office 365.
Você pode modificar o nome do grupo de segurança dinâmico do Microsoft Entra usando comandos do Studio e do PowerShell.
Para modificar o nome do grupo de segurança dinâmico do Microsoft Entra usando o PowerShell:
  1. Abra a janela do PowerShell.
  2. Execute asnp citrix* para carregar os módulos do PowerShell específicos da Citrix.
  3. Execute o comando Set-AcctIdentityPool -AzureAdSeurityGroupName [DSG-Name].
Você receberá mensagens de erro apropriadas se o nome do grupo de segurança dinâmico do Microsoft Entra não puder ser modificado.

Mais informações